@@ -32,7 +32,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program (see the file COPYING); if not, see
- * http://www.gnu.org/licenses/, or contact Free Software Foundation, Inc.,
+ * https://www.gnu.org/licenses/, or contact Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA  02111-1301  USA
  *
  ****************************************************************
@@ -533,8 +533,10 @@ int main(int ac, char** av)
 	    break;
 	  }
 
-	  if (ap[1] == '-' && !strcmp(ap, "--version"))
-	    Panic(0, "Screen version %s", version);
+	  if (ap[1] == '-' && !strcmp(ap, "--version")) {
+	    printf("Screen version %s\n", version);
+	    exit(0);
+	  }
 	  if (ap[1] == '-' && !strcmp(ap, "--help"))
 	    exit_with_usage(myname, NULL, NULL);
 
@@ -786,8 +788,8 @@ int main(int ac, char** av)
             break;
 
           case 'v':
-            Panic(0, "Screen version %s", version);
-            /* NOTREACHED */
+            printf("Screen version %s\n", version);
+            exit(0);
 
 #ifdef UTF8
           case 'U':
@@ -1027,7 +1029,7 @@ int main(int ac, char** av)
       Panic(0, "$TERM too long - sorry.");
 
     GetTTY(0, &attach_Mode);
-#ifdef DEBUGGGGGGGGGGGGGGG
+#ifdef DEBUG
     DebugTTY(&attach_Mode);
 #endif /* DEBUG */
     }
